DotLottieWebView class

Constructors

DotLottieWebView(int viewId, BinaryMessenger messenger)

Properties

canvasElement ↔ HTMLCanvasElement
latefinal
dotLottiePlayer ↔ JSAny?
getter/setter pair
element ↔ HTMLDivElement
latefinal
hashCode → int
The hash code for this object.
no setterinherited
isDisposed ↔ bool
getter/setter pair
isInitialized ↔ bool
getter/setter pair
messenger → BinaryMessenger
final
methodChannel ↔ MethodChannel
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewId → int
final

Methods

activeAnimationId() → String?
activeThemeId() → String?
autoplay() → bool
currentFrame() → double?
currentProgress() → double?
dispose() → void
duration() → double?
getStateMachine(String id) → String?
initialize(Map<String, dynamic> config) → Future<void>
Initialize the DotLottie player with config from Dart
initializeFromParams(Map<String, dynamic> params) → void
isLoaded() → bool
isPaused() → bool
isPlaying() → bool
isStopped() → bool
loadAnimation(String animationId) → void
loop() → bool
loopCount() → int?
manifest() → Map<String, dynamic>?
markers() → List<Map<String, dynamic>>?
mode() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → bool
play() → bool
resetTheme() → bool
resize(int width, int height) → void
segments() → List<double>?
setBackgroundColor(String color) → void
setFrame(double frame) → bool
setLayout(String fit, double alignX, double alignY) → void
setLoop(bool loop) → void
setMarker(String marker) → void
setMode(String mode) → void
setProgress(double progress) → bool
setSegment(double start, double end) → void
setSlots(String slots) → bool
setSpeed(double speed) → void
setTheme(String themeId) → bool
setThemeData(String themeData) → bool
setUseFrameInterpolation(bool useFrameInterpolation) → void
speed() → double?
stateMachineCurrentState() → String?
stateMachineFire(String event) → void
stateMachineGetBooleanInput(String key) → bool?
stateMachineGetInputs() → Map<String, String>?
stateMachineGetNumericInput(String key) → double?
stateMachineGetStringInput(String key) → String?
stateMachineLoad(String stateMachineId) → bool
stateMachineLoadData(String data) → bool
stateMachineSetBooleanInput(String key, bool value) → bool
stateMachineSetNumericInput(String key, double value) → bool
stateMachineSetStringInput(String key, String value) → bool
stateMachineStart() → bool
stateMachineStop() → bool
stop() → bool
toString() → String
A string representation of this object.
inherited
totalFrames() → double?
useFrameInterpolation() → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited